@@ -4,7 +4,7 @@
 # @Author  : chenglongping
 # @File    : __init__.py.py
 from __future__ import unicode_literals
-from amaze_dict import wrap_value
+from amaze_dict.amaze_dict import wrap_value
 
 import logging
 
